@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2013 Derrick Moser <derrick_moser@yahoo.com>
+# Copyright (C) 2006-2014 Derrick Moser <derrick_moser@yahoo.com>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -25,7 +25,7 @@ import platform
 import subprocess
 import sys
 
-VERSION='0.4.7'
+VERSION='0.4.8'
 PACKAGE='1'
 PLATFORM='win' + ''.join([ c for c in platform.architecture()[0] if c.isdigit() ])
 INSTALLER='diffuse-%s-%s.%s' % (VERSION, PACKAGE, PLATFORM)
@@ -103,9 +103,10 @@ copyFile(os.path.join(os.environ['SYSTEMROOT'], 'WinSxS\\Manifests\\x86_Microsof
 
 # include GTK dependencies
 gtk_dir = os.environ['GTK_BASEPATH']
-copyDir(os.path.join(gtk_dir, 'lib'), 'dist\\lib')
 copyDir(os.path.join(gtk_dir, 'etc'), 'dist\\etc')
+copyDir(os.path.join(gtk_dir, 'lib'), 'dist\\lib')
 mkdir('dist\\share')
+copyDir(os.path.join(gtk_dir, 'share\\icons'), 'dist\\share\\icons')
 copyDir(os.path.join(gtk_dir, 'share\\themes'), 'dist\\share\\themes')
 
 #
@@ -119,7 +120,7 @@ for p in glob.glob('..\\src\\usr\\share\\diffuse\\syntax\\*.syntax'):
 copyFile('diffuserc', 'dist\\diffuserc')
 
 # application icon
-copyFile('diffuse.ico', 'dist\\diffuse.ico')
+copyDir('..\\src\\usr\\share\\icons', 'dist\\share\\icons')
 
 # translations
 mkdir('dist\\share\\locale')
